```
python ./make_boat_dot.py
dot -Tpng -o signal_k_observation.png signal_k_observation.dot
```

then feed to AI art gen with a prompt something like:

```
<https://s.mj.run/V6KvxlpftFY> as a hand-drawn engineering design of miniature fishing boats
```


![Fun Mutation of Dot Output](boats2.png)
